@@ -35,7 +35,7 @@ from testflows._core.funcs import load, append_path
 from testflows._core.funcs import main, args, private_key
 from testflows._core.funcs import metric, ticket, value, note, debug, trace
 from testflows._core.funcs import attribute, requirement, tag
-from testflows._core.funcs import input
+from testflows._core.funcs import input, current_time
 from testflows._core.funcs import message, exception, ok, fail, skip, err
 from testflows._core.funcs import result, null, xok, xfail, xerr, xnull, pause, getsattr
 from testflows._core.funcs import current_dir, current_module, load_module
